=======
CHANGES
=======

0.4.1 (2016-02-08)
------------------
* Fix bad dependecy on BeautifoulSoup 

0.4 (2016-02-7)
----------------
* Moar compatibility fixes to API version 1.0 and 1.1
* Get rid of the image_url field, so Compropago can display the store's logo.
* Get MXN->USD rate from Banxico. Cache it for 1 hour

0.3(2016-01-17)
----------------

* Compatibility with API version 1.1


0.2 (2015-12-27)
----------------

* Improve documentation and packaging.

0.1 (2015-12-01)
----------------

* Initial release to PyPI.
* Functional Payment processor.

